//
// LDASTools Generic API - A library of general use algorithms for LDASTools
// Suite
//
// Copyright (C) 2018 California Institute of Technology
//
// LDASTools Generic API is free software; you may redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 (GPLv2) of the
// License or at your discretion, any later version.
//
// LDASTools Generic API is distributed in the hope that it will be useful, but
// without any warranty or even the implied warranty of merchantability
// or fitness for a particular purpose. See the GNU General Public
// License (GPLv2) for more details.
//
// Neither the names of the California Institute of Technology (Caltech),
// The Massachusetts Institute of Technology (M.I.T), The Laser
// Interferometer Gravitational-Wave Observatory (LIGO), nor the names
// of its contributors may be used to endorse or promote products derived
// from this software without specific prior written permission.
//
// You should have received a copy of the licensing terms for this
// software included in the file LICENSE located in the top-level
// directory of this package. If you did not, you can view a copy at
// http://dcc.ligo.org/M1500244/LICENSE
//

#ifdef HAVE_CONFIG_H
#include <ldasgen_config.h>
#endif /* HAVE_CONFIG_H */

//----------------------------------------------------------------------
#include <cstdlib>

#include <time.h>

#include "StatStream.cc"

using std::exit;

// Utility program for doing an lstat call

//=======================================================================
// This thread will watch to see if we become inherited by process 1
//=======================================================================
void*
parent_watch( void* /* Data */ )
{
    while ( 1 )
    {
        if ( getppid( ) == 1 )
        {
            exit( 1 );
        }
        sleep( 5 );
    }
    return ( NULL );
}

int
main( int /* ArgV */, char** /* ArgV */ )
{
    GenericAPI::StatStream stream;
    pthread_t              pw_thread;

    pthread_create( &pw_thread, NULL, parent_watch, NULL );
    try
    {
        while ( 1 )
        {
            //-----------------------------------------------------------------
            // Continuously process events on stdin and send results on stdout
            //-----------------------------------------------------------------
            stream.Process( 0, 1 );
        }
    }
    catch ( ... )
    {
    }
    pthread_join( pw_thread, NULL );
    return ( 0 );
}
